==> google_applovin_unity_ads-2.2.4.tar.gz: android/src/main/java/com/btcpiyush/ads/google_applovin_unity_ads/FlutterAppLovinBannerAd.java <==
// Copyright 2022 Bitcoding
// See the License for the specific language governing permissions and
// limitations under the License.

package com.btcpiyush.ads.google_applovin_unity_ads;


import android.content.res.Resources;
import android.view.Gravity;
import android.view.ViewGroup.LayoutParams;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;

import com.applovin.mediation.ads.MaxAdView;
import com.applovin.sdk.AppLovinSdk;

import io.flutter.plugin.platform.PlatformView;
import io.flutter.util.Preconditions;

/**
 * A wrapper for {@link MaxAdView}.
 */
class FlutterAppLovinBannerAd extends FlutterAd implements FlutterAdLoadedListener {

    @NonNull
    protected final AdInstanceManager manager;
    @NonNull
    private final String adUnitId;
    @NonNull
    private final FlutterAdSize size;
    @NonNull
    private final AppLovinSdk _appLovinSdk;
    @NonNull
    private final BannerAdCreator bannerAdCreator;
    @Nullable
    protected MaxAdView adView;

    /**
     * Constructs a `FlutterAdManagerBannerAd`.
     *
     * <p>Call `load()` to instantiate the `AdView` and load the `AdRequest`. `getView()` will return
     * null only until `load` is called.
     */
    public FlutterAppLovinBannerAd(
            int adId,
            @NonNull AdInstanceManager manager,
            @NonNull String adUnitId,
            @NonNull FlutterAdSize size,
            @NonNull AppLovinSdk _appLovinSdk,
            @NonNull BannerAdCreator bannerAdCreator) {
        super(adId);
        Preconditions.checkNotNull(manager);
        Preconditions.checkNotNull(adUnitId);
        Preconditions.checkNotNull(size);
        Preconditions.checkNotNull(_appLovinSdk);
        this.manager = manager;
        this.adUnitId = adUnitId;
        this._appLovinSdk = _appLovinSdk;
        this.size = size;
        this.bannerAdCreator = bannerAdCreator;
    }

    @Override
    void load() {
        adView = bannerAdCreator.createAppLovinAdView(adUnitId, _appLovinSdk);
        if (adView == null) {
            return;
        }
        int width  = LayoutParams.MATCH_PARENT;
        int height = (int) (size.getAdSize().getHeight() * Resources.getSystem().getDisplayMetrics().density);
        adView.setGravity(Gravity.CENTER);
        adView.setLayoutParams(new LayoutParams(width, height));
        adView.setListener(new FlutterBannerAdListener(adId, manager, this));
        adView.loadAd();
        adView.startAutoRefresh();
    }

    @Override
    public void onAdLoaded() {
        if (adView != null) {
            manager.onAdLoaded(adId, null);
        }
    }

    @Nullable
    @Override
    PlatformView getPlatformView() {
        if (adView == null) {
            return null;
        }
        return new FlutterPlatformView(adView);
    }

    @Override
    void dispose() {
        if (adView != null) {
            adView.destroy();
            adView = null;
        }
    }

    @Nullable
    FlutterAdSize getAdSize() {
        if (adView == null || size.getAdSize() == null) {
            return null;
        }
        return new FlutterAdSize(size.getAdSize());
    }
}

==> google_applovin_unity_ads-2.3.3.tar.gz: android/src/main/java/com/btcpiyush/ads/google_applovin_unity_ads/FlutterAppLovinBannerAd.java <==
// Copyright 2022 Bitcoding
// See the License for the specific language governing permissions and
// limitations under the License.

package com.btcpiyush.ads.google_applovin_unity_ads;


import android.content.res.Resources;
import android.view.Gravity;
import android.view.ViewGroup.LayoutParams;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;

import com.applovin.mediation.ads.MaxAdView;
import com.applovin.sdk.AppLovinSdk;

import io.flutter.plugin.platform.PlatformView;
import io.flutter.util.Preconditions;

/**
 * A wrapper for {@link MaxAdView}.
 */
class FlutterAppLovinBannerAd extends FlutterAd implements FlutterAdLoadedListener {

    @NonNull
    protected final AdInstanceManager manager;
    @NonNull
    private final String adUnitId;
    @NonNull
    private final FlutterAdSize size;
    @NonNull
    private final AppLovinSdk _appLovinSdk;
    @Nullable
    private GoogleApplovinUnityAdsPlugin.GeoedgeSdkFactory geoSdkFactory;
    @NonNull
    private final BannerAdCreator bannerAdCreator;
    @Nullable
    protected MaxAdView adView;

    /**
     * Constructs a `FlutterAdManagerBannerAd`.
     *
     * <p>Call `load()` to instantiate the `AdView` and load the `AdRequest`. `getView()` will return
     * null only until `load` is called.
     */
    public FlutterAppLovinBannerAd(
            int adId,
            @NonNull AdInstanceManager manager,
            @NonNull String adUnitId,
            @NonNull FlutterAdSize size,
            @NonNull AppLovinSdk _appLovinSdk,
            @NonNull BannerAdCreator bannerAdCreator,
            GoogleApplovinUnityAdsPlugin.GeoedgeSdkFactory sdkFactory) {
        super(adId);
        Preconditions.checkNotNull(manager);
        Preconditions.checkNotNull(adUnitId);
        Preconditions.checkNotNull(size);
        Preconditions.checkNotNull(_appLovinSdk);
        this.manager = manager;
        this.adUnitId = adUnitId;
        this._appLovinSdk = _appLovinSdk;
        this.size = size;
        this.bannerAdCreator = bannerAdCreator;
        this.geoSdkFactory = sdkFactory;
    }

    @Override
    void load() {
        adView = bannerAdCreator.createAppLovinAdView(adUnitId, _appLovinSdk);
        if (adView == null) {
            return;
        }
        int width  = LayoutParams.MATCH_PARENT;
        int height = (int) (size.getAdSize().getHeight() * Resources.getSystem().getDisplayMetrics().density);
        adView.setGravity(Gravity.CENTER);
        adView.setLayoutParams(new LayoutParams(width, height));
        adView.setListener(new FlutterBannerAdListener(adId, manager, this));
        if (geoSdkFactory != null) {
            geoSdkFactory.addBannerAd(adView);
        }
        adView.loadAd();
//        adView.startAutoRefresh();
    }

    @Override
    public void onAdLoaded() {
        if (adView != null) {
            manager.onAdLoaded(adId, null);
        }
    }

    @Nullable
    @Override
    PlatformView getPlatformView() {
        if (adView == null) {
            return null;
        }
        return new FlutterPlatformView(adView);
    }

    @Override
    void dispose() {
        if (adView != null) {
            adView.destroy();
            adView = null;
        }
    }

    @Nullable
    FlutterAdSize getAdSize() {
        if (adView == null || size.getAdSize() == null) {
            return null;
        }
        return new FlutterAdSize(size.getAdSize());
    }
}
